@@ -3,7 +3,9 @@ import requests
 from lxml import etree
 from gzip import GzipFile
 from website_sitemap_parser.elements import NewsPage, Page, Sitemap, RootSitemap
-from website_sitemap_parser.config import DEFAULT_COOKIES, DEFAULT_HEADERS, DEFAULT_TIMEOUT
+from website_sitemap_parser.config import DEFAULT_COOKIES, DEFAULT_HEADERS, DEFAULT_TIMEOUT, DEFAULT_READ_TIMEOUT
+
+from stopit import ThreadingTimeout as Timeout, TimeoutException
 
 
 def get_element_values(elem):
@@ -59,50 +61,54 @@ def parse(url, timeout=None, headers=None, cookies=None, include_root_sitemap=Fa
     context = etree.iterparse(stream, events=('end',), tag=['{*}url', '{*}sitemap'])
 
     try:
-        for action, elem in context:
-            tag = "".join(elem.tag.split('}')[1:])
+        with Timeout(DEFAULT_READ_TIMEOUT):
+            for action, elem in context:
+                tag = "".join(elem.tag.split('}')[1:])
 
-            values = get_element_values(elem)
+                values = get_element_values(elem)
 
-            if not values.get('loc'):
-                logging.warning(f'Missing location for element: {tag} {values}')
-                continue
+                if not values.get('loc'):
+                    logging.warning(f'Missing location for element: {tag} {values}')
+                    continue
 
-            if tag == 'url' and 'news' in values:
-                news_values = values.get('news') or {}
-                yield NewsPage(
-                    url=values['loc'],
-                    last_modified=values.get('lastmod'),
-                    priority=values.get('priority'),
-                    change_freq=values.get('changefreq'),
-                    publication_date=news_values.get('publication_date'),
-                    title=news_values.get('title'),
-                    keywords=news_values.get('keywords'),
-                    genres=news_values.get('genres'),
-                    # image=
-                )
-            elif tag == 'url':
-                yield Page(
-                    url=values['loc'],
-                    last_modified=values.get('lastmod'),
-                    priority=values.get('priority'),
-                    change_freq=values.get('changefreq')
-                )
-            elif tag == 'sitemap':
-                yield Sitemap(
-                    url=values['loc'],
-                    last_modified=values.get('lastmod'),
-                    priority=values.get('priority'),
-                    change_freq=values.get('changefreq')
-                )
+                if tag == 'url' and 'news' in values:
+                    news_values = values.get('news') or {}
+                    yield NewsPage(
+                        url=values['loc'],
+                        last_modified=values.get('lastmod'),
+                        priority=values.get('priority'),
+                        change_freq=values.get('changefreq'),
+                        publication_date=news_values.get('publication_date'),
+                        title=news_values.get('title'),
+                        keywords=news_values.get('keywords'),
+                        genres=news_values.get('genres'),
+                        # image=
+                    )
+                elif tag == 'url':
+                    yield Page(
+                        url=values['loc'],
+                        last_modified=values.get('lastmod'),
+                        priority=values.get('priority'),
+                        change_freq=values.get('changefreq')
+                    )
+                elif tag == 'sitemap':
+                    yield Sitemap(
+                        url=values['loc'],
+                        last_modified=values.get('lastmod'),
+                        priority=values.get('priority'),
+                        change_freq=values.get('changefreq')
+                    )
 
-            elem.clear()
-            while elem.getprevious() is not None:
-                if elem.getparent() is not None:
-                    del elem.getparent()[0]
+                elem.clear()
+                while elem.getprevious() is not None:
+                    if elem.getparent() is not None:
+                        del elem.getparent()[0]
     except etree.XMLSyntaxError as e:
         logging.warning(f'Failed processing: {url} due to {e}')
         return []
+    except TimeoutException:
+        logging.warning(f'Timeout exception: {url}')
+        return []
 
     if include_root_sitemap:
         yield RootSitemap(url=url)
@@ -111,4 +117,4 @@ def parse(url, timeout=None, headers=None, cookies=None, include_root_sitemap=Fa
 
 
 if __name__ == '__main__':
-    print(list(parse('https://www.volkskrant.nl/sitemap/sitemap-21.txt')))
\ No newline at end of file
+    print(list(parse('http://ipv4.download.thinkbroadband.com/1GB.zip')))
\ No newline at end of file
